import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import * as i1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { RxPush } from '@rx-angular/template/push';
import { DEFAULT_HTML5_DATE_TIME_FORMAT, DEFAULT_GERMAN_HUMAN_DATE_TIME_FORMAT } from '@smallstack/utils';
import { format, parse } from 'date-fns';
import { BehaviorSubject, map, combineLatest } from 'rxjs';
import { F as FilterBaseWidgetComponent } from './smallstack-form-widgets-filter-base-widget.component-1bb6ed87.mjs';
import '@angular/router';
import '@smallstack/common-components';
import '@smallstack/widget-core';
import 'uuid';

class DateFilterWidgetComponent extends FilterBaseWidgetComponent {
    constructor() {
        super();
        this.inputFrom$ = new BehaviorSubject(undefined);
        this.inputTo$ = new BehaviorSubject(undefined);
        this.inputFromFormatted$ = this.inputFrom$.pipe(map((value) => value
            ? format(parse(value, DEFAULT_HTML5_DATE_TIME_FORMAT, new Date()), DEFAULT_GERMAN_HUMAN_DATE_TIME_FORMAT)
            : undefined));
        this.inputToFormatted$ = this.inputTo$.pipe(map((value) => value
            ? format(parse(value, DEFAULT_HTML5_DATE_TIME_FORMAT, new Date()), DEFAULT_GERMAN_HUMAN_DATE_TIME_FORMAT)
            : undefined));
        this.subscription.add(combineLatest([this.value$, this.path$]).subscribe(([value, path]) => {
            if (value) {
                if (value[path]?.$gte)
                    this.inputFrom$.next(format(value[path].$gte, DEFAULT_HTML5_DATE_TIME_FORMAT));
                if (value[path]?.$lte)
                    this.inputTo$.next(format(value[path].$lte, DEFAULT_HTML5_DATE_TIME_FORMAT));
            }
            else {
                this.inputFrom$.next(undefined);
                this.inputTo$.next(undefined);
            }
        }));
        this.subscription.add(combineLatest([this.inputFrom$, this.inputTo$, this.path$]).subscribe(([from, to, path]) => {
            if (from || to) {
                const filter = {};
                if (from)
                    filter.$gte = parse(from, DEFAULT_HTML5_DATE_TIME_FORMAT, new Date()).valueOf();
                if (to)
                    filter.$lte = parse(to, DEFAULT_HTML5_DATE_TIME_FORMAT, new Date()).valueOf();
                void this.setFilter({ [path]: filter });
            }
            else
                void this.setFilter(undefined);
        }));
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DateFilterWidgetComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: DateFilterWidgetComponent, isStandalone: true, selector: "smallstack-date-filter-widget", usesInheritance: true, ngImport: i0, template: "<input\n  #from\n  type=\"datetime-local\"\n  placeholder=\"von\"\n  class=\"input input-bordered invisible absolute\"\n  [ngModel]=\"inputFrom$ | push\"\n  (ngModelChange)=\"inputFrom$.next($event)\"\n  [max]=\"inputTo$ | push\"\n/>\n<input\n  #to\n  type=\"datetime-local\"\n  placeholder=\"bis\"\n  class=\"input input-bordered invisible absolute\"\n  [ngModel]=\"inputTo$ | push\"\n  (ngModelChange)=\"inputTo$.next($event)\"\n  [min]=\"inputFrom$ | push\"\n/>\n<div class=\"join w-full\">\n  <input\n    (click)=\"from.showPicker()\"\n    placeholder=\"von\"\n    type=\"string\"\n    [ngModel]=\"inputFromFormatted$ | push\"\n    class=\"input input-bordered w-full join-item\"\n    readonly\n  />\n  <input\n    (click)=\"to.showPicker()\"\n    placeholder=\"bis\"\n    type=\"string\"\n    [ngModel]=\"inputToFormatted$ | push\"\n    class=\"input input-bordered w-full join-item\"\n    readonly\n  />\n</div>\n", dependencies: [{ kind: "pipe", type: RxPush, name: "push" }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: DateFilterWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-date-filter-widget", standalone: true, imports: [RxPush, FormsModule], changeDetection: ChangeDetectionStrategy.OnPush, template: "<input\n  #from\n  type=\"datetime-local\"\n  placeholder=\"von\"\n  class=\"input input-bordered invisible absolute\"\n  [ngModel]=\"inputFrom$ | push\"\n  (ngModelChange)=\"inputFrom$.next($event)\"\n  [max]=\"inputTo$ | push\"\n/>\n<input\n  #to\n  type=\"datetime-local\"\n  placeholder=\"bis\"\n  class=\"input input-bordered invisible absolute\"\n  [ngModel]=\"inputTo$ | push\"\n  (ngModelChange)=\"inputTo$.next($event)\"\n  [min]=\"inputFrom$ | push\"\n/>\n<div class=\"join w-full\">\n  <input\n    (click)=\"from.showPicker()\"\n    placeholder=\"von\"\n    type=\"string\"\n    [ngModel]=\"inputFromFormatted$ | push\"\n    class=\"input input-bordered w-full join-item\"\n    readonly\n  />\n  <input\n    (click)=\"to.showPicker()\"\n    placeholder=\"bis\"\n    type=\"string\"\n    [ngModel]=\"inputToFormatted$ | push\"\n    class=\"input input-bordered w-full join-item\"\n    readonly\n  />\n</div>\n" }]
        }], ctorParameters: function () { return []; } });

export { DateFilterWidgetComponent };
//# sourceMappingURL=smallstack-form-widgets-date-filter-widget.component-51b14125.mjs.map
