import * as i0 from '@angular/core';
import { inject, Directive } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { RouterUtilService } from '@smallstack/common-components';
import { filterNullish, distinctUntilChangedObj } from '@smallstack/utils';
import { BaseWidgetComponent, FormService } from '@smallstack/widget-core';
import { map, combineLatest, switchMap, of, firstValueFrom } from 'rxjs';
import { v4 } from 'uuid';

class FilterBaseWidgetComponent extends BaseWidgetComponent {
    constructor() {
        super(...arguments);
        this.formService = inject(FormService);
        this.routerUtilsService = inject(RouterUtilService);
        this.uuid = v4();
        /** original path of the form field (without overrides) */
        this.originalPath$ = this.data$.pipe(map((data) => data.path), filterNullish());
        this.activatedRoute = inject(ActivatedRoute);
        this.urlSyncValue$ = combineLatest([this.originalPath$, this.activatedRoute.queryParams]).pipe(map(([path, params]) => {
            return params["filter_" + path];
        }));
        /** value of the form field */
        this.value$ = this.formService.value$.pipe(map((value) => (value ? value[this.uuid] : undefined)), distinctUntilChangedObj());
        /** original schema without overrides */
        this.originalSchema$ = this.originalPath$.pipe(switchMap((path) => this.formService.getSchemaForPath$(path)));
        /** schema of the form field */
        this.schema$ = combineLatest([this.originalSchema$, this.data$]).pipe(map(([originalSchema, data]) => {
            if (data?.filterSchema)
                return data.filterSchema;
            else
                return originalSchema;
        }));
        /** path of the form field */
        this.path$ = this.schema$.pipe(switchMap((schema) => {
            if (schema["x-schema-form"]?.filterPath)
                return of(schema["x-schema-form"].filterPath);
            else
                return this.originalPath$;
        }));
    }
    async setFilter(value) {
        let currentValue = this.formService.getValue();
        if (!currentValue)
            currentValue = {};
        if (value === undefined)
            delete currentValue[this.uuid];
        else
            currentValue[this.uuid] = value;
        this.formService.setValue(currentValue);
    }
    async setUrlSyncParam(value) {
        const path = await firstValueFrom(this.originalPath$);
        if (value === undefined)
            await this.routerUtilsService.removeSearchParameter("filter_" + path);
        else
            await this.routerUtilsService.addSearchParameter("filter_" + path, "" + value);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: FilterBaseWidgetComponent, deps: null, target: i0.ɵɵFactoryTarget.Directive }); }
    static { this.ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.8", type: FilterBaseWidgetComponent, usesInheritance: true, ngImport: i0 }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: FilterBaseWidgetComponent, decorators: [{
            type: Directive
        }] });

export { FilterBaseWidgetComponent as F };
//# sourceMappingURL=smallstack-form-widgets-filter-base-widget.component-1bb6ed87.mjs.map
