import { CommonModule } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy } from '@angular/core';
import { LoadingElementDirective } from '@smallstack/common-components';
import { Logger } from '@smallstack/core-common';
import * as i2 from '@smallstack/i18n-components';
import * as i1 from '@smallstack/typesystem-client';
import { getJsonByPath } from '@smallstack/utils';
import { BaseWidgetComponent } from '@smallstack/widget-core';
import { a as CONFIGURATION_KEYS, b as SOCKETS } from './smallstack-form-widgets-smallstack-form-widgets-05e5b8f6.mjs';
import '@smallstack/axios-api-client';

class SaveModelBtnWidgetComponent extends BaseWidgetComponent {
    constructor(frontendTypeRegistry, notificationService) {
        super();
        this.frontendTypeRegistry = frontendTypeRegistry;
        this.notificationService = notificationService;
    }
    saveModel() {
        return async () => {
            try {
                const model = getJsonByPath(this.widgetTreeService.getGlobalsSnapshot(), this.data?.[CONFIGURATION_KEYS.GLOBAL_VARIABLE_NAME]);
                if (model) {
                    const type = await this.frontendTypeRegistry.getTypeByPath(this.data?.[CONFIGURATION_KEYS.TYPE_PATH]);
                    const i18nKey = this.frontendTypeRegistry.getI18nTitle(type);
                    const crud = this.frontendTypeRegistry.getCrud(this.data?.[CONFIGURATION_KEYS.TYPE_PATH]);
                    if (crud && type) {
                        if (model.id)
                            await this.notificationService.handlePromise(crud.put(model), {
                                successMsg: i18nKey + " wurde gespeichert!",
                                rethrowException: true
                            });
                        else
                            await this.notificationService.handlePromise(crud.create(model), {
                                successMsg: i18nKey + " wurde gespeichert!",
                                rethrowException: true
                            });
                        await this.sendSocketData(SOCKETS.SAVED_SUCCESSFULLY, true);
                        if (this.widgetTreeService.dialogRef)
                            this.widgetTreeService.dialogRef.close();
                    }
                    else
                        Logger.warning("SaveModelBtnWidgetComponent", "No CRUD found for path '" + this.data?.[CONFIGURATION_KEYS.TYPE_PATH] + "'!");
                }
                else
                    Logger.warning("SaveModelBtnWidgetComponent", "No model found for path '" + this.data?.[CONFIGURATION_KEYS.GLOBAL_VARIABLE_NAME] + "' on global store!");
            }
            finally {
                await this.sendSocketData(SOCKETS.SAVED_SUCCESSFULLY, false);
            }
        };
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: SaveModelBtnWidgetComponent, deps: [{ token: i1.FrontendTypeRegistry }, { token: i2.NotificationService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: SaveModelBtnWidgetComponent, isStandalone: true, selector: "smallstack-save-model-btn-widget", usesInheritance: true, ngImport: i0, template: "<button class=\"btn btn-primary btn-sm w-full\" [loadingFn]=\"saveModel()\">{{ data.btnText || \"Speichern\" }}</button>\n", styles: [""], dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: LoadingElementDirective, selector: "[loadingFn]", inputs: ["loadingFn", "isLoading"], exportAs: ["loadingFn"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: SaveModelBtnWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-save-model-btn-widget", standalone: true, imports: [CommonModule, LoadingElementDirective], changeDetection: ChangeDetectionStrategy.OnPush, template: "<button class=\"btn btn-primary btn-sm w-full\" [loadingFn]=\"saveModel()\">{{ data.btnText || \"Speichern\" }}</button>\n" }]
        }], ctorParameters: function () { return [{ type: i1.FrontendTypeRegistry }, { type: i2.NotificationService }]; } });

export { SaveModelBtnWidgetComponent };
//# sourceMappingURL=smallstack-form-widgets-save-model-btn-widget.component-324362d7.mjs.map
