import { A11yModule } from '@angular/cdk/a11y';
import { DOCUMENT } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy, Inject } from '@angular/core';
import * as i1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { RxVirtualFor, RxVirtualScrollViewportComponent, FixedSizeVirtualScrollStrategy } from '@rx-angular/template/experimental/virtual-scrolling';
import { RxFor } from '@rx-angular/template/for';
import { RxIf } from '@rx-angular/template/if';
import { RxPush } from '@rx-angular/template/push';
import { OverlayComponent } from '@smallstack/common-components';
import * as i2 from '@smallstack/i18n-components';
import { I18nComponent } from '@smallstack/i18n-components';
import { IconComponent } from '@smallstack/theme-components';
import { filterNullish, cloneObject } from '@smallstack/utils';
import { map, BehaviorSubject, combineLatest, pairwise, firstValueFrom } from 'rxjs';
import { F as FilterBaseWidgetComponent } from './smallstack-form-widgets-filter-base-widget.component-1bb6ed87.mjs';
import { g as getSelectOptions$ } from './smallstack-form-widgets-select-rxjs-helpers-dac39fca.mjs';
import '@angular/router';
import '@smallstack/widget-core';
import 'uuid';
import '@smallstack/core-common';
import '@smallstack/typesystem-client';
import 'fuse.js';

class SelectFilterWidgetComponent extends FilterBaseWidgetComponent {
    constructor(document, translationStore) {
        super();
        this.document = document;
        this.translationStore = translationStore;
        this.type$ = this.schema$.pipe(map((schema) => schema["x-schema-form"].type));
        this.searchText$ = new BehaviorSubject(undefined);
        this.selectOptions$ = getSelectOptions$(this.schema$, this.searchText$);
        this.currentValues$ = new BehaviorSubject([]);
        this.selectedValueString$ = combineLatest([this.currentValues$, this.selectOptions$]).pipe(filterNullish(), map(([values, options]) => {
            return values
                .map((val) => {
                const option = options.find((option) => option.value === val);
                if (option)
                    return this.translationStore.translate(option.label);
                else
                    return val;
            })
                .join(", ");
        }));
        // sync value
        this.subscription.add(this.value$
            .pipe(pairwise(), map(([oldValue, newValue]) => {
            // this would be an external reset, so we need to clear currentValues$
            if (oldValue !== undefined && newValue === undefined)
                this.currentValues$.next([]);
        }))
            .subscribe());
        // sync url value
        this.subscription.add(this.urlSyncValue$.subscribe(async (urlValue) => {
            if (urlValue) {
                const values = urlValue.split(",");
                this.currentValues$.next(values);
                await this.updateFilter();
            }
        }));
    }
    async selectValue(newValue) {
        // update currentValues$
        if (this.currentValues$.value.includes(newValue))
            this.currentValues$.next(this.currentValues$.value.filter((value) => value !== newValue));
        else
            this.currentValues$.next([...this.currentValues$.value, newValue]);
        // update filter value
        await this.updateFilter();
    }
    async removeFilter() {
        this.currentValues$.next([]);
        await this.setFilter(undefined);
    }
    async addCurrent() {
        const options = await firstValueFrom(this.selectOptions$);
        // update currentValues$
        let currentValues = cloneObject(this.currentValues$.getValue());
        for (const option of options)
            if (!currentValues.includes(option.value))
                currentValues = [...currentValues, option.value];
        this.currentValues$.next(currentValues);
        // update filter value
        await this.updateFilter();
    }
    async updateFilter() {
        const path = await firstValueFrom(this.path$);
        if (this.currentValues$.value.length === 0) {
            await this.setFilter(undefined);
            await this.setUrlSyncParam(undefined);
        }
        else if (this.currentValues$.value.length === 1) {
            await this.setFilter({ [path]: this.currentValues$.value[0] });
            await this.setUrlSyncParam(this.currentValues$.value[0]);
        }
        else {
            await this.setFilter({ $or: this.currentValues$.value.map((val) => ({ [path]: val })) });
            await this.setUrlSyncParam(this.currentValues$.value.join(","));
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: SelectFilterWidgetComponent, deps: [{ token: DOCUMENT }, { token: i2.TranslationStore }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: SelectFilterWidgetComponent, isStandalone: true, selector: "smallstack-select-filter-widget", usesInheritance: true, ngImport: i0, template: "<div (click)=\"overlay.openOverlay()\" class=\"join w-full cursor-pointer\">\n  <input type=\"text\" class=\"input input-bordered w-full join-item\" readonly [ngModel]=\"selectedValueString$ | push\" />\n  <button (click)=\"overlay.openOverlay()\" class=\"btn btn-primary join-item\" tabindex=\"-1\"\n    ><span class=\"font-bold text-lg\">\u23F7</span></button\n  >\n</div>\n<smallstack-overlay #overlay>\n  <div class=\"input-dropdown flex flex-col gap-2 p-1 h-96\" style=\"min-width: 24rem\">\n    <input\n      cdkFocusInitial\n      type=\"search\"\n      class=\"input input-sm input-bordered w-full\"\n      placeholder=\"Auswahl filtern...\"\n      [ngModel]=\"searchText$ | push\"\n      (ngModelChange)=\"searchText$.next($event)\"\n    />\n\n    <div *rxIf=\"!(selectOptions$ | push)?.length\" class=\"text-center italic text-help p-2\">\n      Keine Eintr\u00E4ge gefunden\n    </div>\n\n    <rx-virtual-scroll-viewport [itemSize]=\"32\">\n      <ul class=\"menu menu-sm p-0\">\n        <li\n          *rxVirtualFor=\"let option of selectOptions$\"\n          (click)=\"selectValue(option.value)\"\n          class=\"h-8 whitespace-nowrap p-0\"\n          ><a>\n            <input\n              type=\"checkbox\"\n              class=\"checkbox checkbox-primary checkbox-md\"\n              [checked]=\"(currentValues$ | push)?.includes(option.value)\"\n            />\n            <smallstack-i18n [data]=\"$any(option.label)\"></smallstack-i18n>\n          </a>\n        </li>\n      </ul>\n    </rx-virtual-scroll-viewport>\n    <div class=\"flex flex-row gap-1 justify-evenly\">\n      <button (click)=\"addCurrent()\" class=\"btn btn-sm btn-secondary\" data-test=\"select-input-overlay-reset\"\n        >Auswahl hinzuf\u00FCgen</button\n      >\n      <button (click)=\"overlay.closeOverlay()\" class=\"btn btn-sm btn-secondary\">schlie\u00DFen</button>\n      <button (click)=\"removeFilter(); overlay.closeOverlay()\" class=\"btn btn-sm btn-secondary\">l\u00F6schen</button>\n    </div>\n  </div>\n</smallstack-overlay>\n", dependencies: [{ kind: "pipe", type: RxPush, name: "push" }, { kind: "directive", type: RxIf, selector: "[rxIf]", inputs: ["rxIf", "rxIfStrategy", "rxIfElse", "rxIfThen", "rxIfSuspense", "rxIfComplete", "rxIfError", "rxIfContextTrigger", "rxIfNextTrigger", "rxIfSuspenseTrigger", "rxIfErrorTrigger", "rxIfCompleteTrigger", "rxIfParent", "rxIfPatchZone", "rxIfRenderCallback"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: I18nComponent, selector: "smallstack-i18n", inputs: ["data", "showMissingKey", "replacers", "locale", "translationStore"] }, { kind: "component", type: OverlayComponent, selector: "smallstack-overlay", inputs: ["hasBackdrop"] }, { kind: "directive", type: RxVirtualFor, selector: "[rxVirtualFor][rxVirtualForOf]", inputs: ["rxVirtualForOf", "rxVirtualForTemplate", "rxVirtualForStrategy", "rxVirtualForTemplateCacheSize", "rxVirtualForParent", "rxVirtualForPatchZone", "rxVirtualForTrackBy", "rxVirtualForRenderCallback"] }, { kind: "component", type: RxVirtualScrollViewportComponent, selector: "rx-virtual-scroll-viewport", outputs: ["viewRange", "scrolledIndexChange"] }, { kind: "directive", type: FixedSizeVirtualScrollStrategy, selector: "rx-virtual-scroll-viewport[itemSize]", inputs: ["itemSize", "runwayItems", "runwayItemsOpposite"] }, { kind: "ngmodule", type: A11yModule }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: SelectFilterWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-select-filter-widget", standalone: true, imports: [
                        RxPush,
                        RxIf,
                        RxFor,
                        FormsModule,
                        IconComponent,
                        I18nComponent,
                        OverlayComponent,
                        RxVirtualFor,
                        RxVirtualScrollViewportComponent,
                        FixedSizeVirtualScrollStrategy,
                        A11yModule
                    ], changeDetection: ChangeDetectionStrategy.OnPush, template: "<div (click)=\"overlay.openOverlay()\" class=\"join w-full cursor-pointer\">\n  <input type=\"text\" class=\"input input-bordered w-full join-item\" readonly [ngModel]=\"selectedValueString$ | push\" />\n  <button (click)=\"overlay.openOverlay()\" class=\"btn btn-primary join-item\" tabindex=\"-1\"\n    ><span class=\"font-bold text-lg\">\u23F7</span></button\n  >\n</div>\n<smallstack-overlay #overlay>\n  <div class=\"input-dropdown flex flex-col gap-2 p-1 h-96\" style=\"min-width: 24rem\">\n    <input\n      cdkFocusInitial\n      type=\"search\"\n      class=\"input input-sm input-bordered w-full\"\n      placeholder=\"Auswahl filtern...\"\n      [ngModel]=\"searchText$ | push\"\n      (ngModelChange)=\"searchText$.next($event)\"\n    />\n\n    <div *rxIf=\"!(selectOptions$ | push)?.length\" class=\"text-center italic text-help p-2\">\n      Keine Eintr\u00E4ge gefunden\n    </div>\n\n    <rx-virtual-scroll-viewport [itemSize]=\"32\">\n      <ul class=\"menu menu-sm p-0\">\n        <li\n          *rxVirtualFor=\"let option of selectOptions$\"\n          (click)=\"selectValue(option.value)\"\n          class=\"h-8 whitespace-nowrap p-0\"\n          ><a>\n            <input\n              type=\"checkbox\"\n              class=\"checkbox checkbox-primary checkbox-md\"\n              [checked]=\"(currentValues$ | push)?.includes(option.value)\"\n            />\n            <smallstack-i18n [data]=\"$any(option.label)\"></smallstack-i18n>\n          </a>\n        </li>\n      </ul>\n    </rx-virtual-scroll-viewport>\n    <div class=\"flex flex-row gap-1 justify-evenly\">\n      <button (click)=\"addCurrent()\" class=\"btn btn-sm btn-secondary\" data-test=\"select-input-overlay-reset\"\n        >Auswahl hinzuf\u00FCgen</button\n      >\n      <button (click)=\"overlay.closeOverlay()\" class=\"btn btn-sm btn-secondary\">schlie\u00DFen</button>\n      <button (click)=\"removeFilter(); overlay.closeOverlay()\" class=\"btn btn-sm btn-secondary\">l\u00F6schen</button>\n    </div>\n  </div>\n</smallstack-overlay>\n" }]
        }], ctorParameters: function () { return [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: i2.TranslationStore }]; } });

export { SelectFilterWidgetComponent };
//# sourceMappingURL=smallstack-form-widgets-select-filter-widget.component-d9a5b42a.mjs.map
