import * as i2 from '@angular/common';
import { DOCUMENT, CommonModule, JsonPipe } from '@angular/common';
import * as i0 from '@angular/core';
import { Component, ChangeDetectionStrategy, Inject, ViewChild } from '@angular/core';
import * as i1$1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { RxFor } from '@rx-angular/template/for';
import { RxIf } from '@rx-angular/template/if';
import { RxLet } from '@rx-angular/template/let';
import { RxPush } from '@rx-angular/template/push';
import { OverlayComponent, LoadingElementDirective, UrlConformPipe } from '@smallstack/common-components';
import { I18nComponent } from '@smallstack/i18n-components';
import { isInlineTranslation } from '@smallstack/i18n-shared';
import * as i1 from '@smallstack/typesystem-client';
import { TypeDetailsComponent } from '@smallstack/typesystem-client';
import { IconComponent } from '@smallstack/theme-components';
import { filterNullish, onlyUnique } from '@smallstack/utils';
import { FormInputContainerComponent } from '@smallstack/widget-core';
import { map, BehaviorSubject, combineLatest, firstValueFrom } from 'rxjs';
import { I as InputBaseWidgetComponent } from './smallstack-form-widgets-input-base-widget.component-e4949b87.mjs';
import { g as getSelectOptions$ } from './smallstack-form-widgets-select-rxjs-helpers-dac39fca.mjs';
import { isArray } from 'class-validator';
import '@smallstack/core-common';
import 'fuse.js';

class SelectInputWidgetComponent extends InputBaseWidgetComponent {
    constructor(document, smallstackTypeRegistry, rxCollectionService) {
        super();
        this.document = document;
        this.smallstackTypeRegistry = smallstackTypeRegistry;
        this.rxCollectionService = rxCollectionService;
        this.isArray = isArray;
        this.multiple$ = this.schema$.pipe(filterNullish(), map((schema) => {
            return schema["x-schema-form"]?.["multiple"] === true;
        }));
        this.showDetails$ = this.schema$.pipe(filterNullish(), map((schema) => {
            return schema["x-schema-form"]?.showDetails === true;
        }));
        this.showAddBtn$ = this.schema$.pipe(filterNullish(), map((schema) => {
            return schema["x-schema-form"]?.["showAddBtn"];
        }));
        this.searchText$ = new BehaviorSubject(undefined);
        this.type$ = this.schema$.pipe(filterNullish(), map((schema) => {
            return schema["x-schema-form"]?.type;
        }));
        this.availableOptions$ = getSelectOptions$(this.schema$);
        this.selectOptions$ = getSelectOptions$(this.schema$, this.searchText$);
        this.selectedValue$ = combineLatest([this.value$, this.availableOptions$]).pipe(map(([value, options]) => {
            if (!value)
                return undefined;
            if (isInlineTranslation(value))
                return this.translationStore.translateInline(value);
            const valuesArray = Array.isArray(value) ? value : [value];
            return valuesArray
                .map((val) => {
                const option = options.find((option) => option.value === val);
                if (option)
                    return this.translationStore.translate(option.label);
                else
                    return this.translationStore.translate(val);
            })
                .join(", ");
        }));
        this.allShownAreSelected$ = combineLatest([this.value$, this.selectOptions$]).pipe(map(([value, options]) => {
            if (!value)
                return false;
            const valuesArray = Array.isArray(value) ? value : [value];
            if (valuesArray.length === 0)
                return false;
            if (valuesArray.length !== options.length)
                return false;
            return options.every((option) => valuesArray.includes(option.value));
        }));
    }
    async selectValue(val) {
        const isMultiple = await firstValueFrom(this.multiple$);
        if (isMultiple) {
            const values = await firstValueFrom(this.value$);
            if (!values)
                val = [val];
            else if (!Array.isArray(values))
                val = [values, val];
            else if (values.includes(val))
                val = values.filter((v) => v !== val);
            else
                val = [...values, val];
        }
        else {
            this.searchText$.next(undefined);
            this.overlay.closeOverlay();
        }
        await this.setValue(val);
    }
    add() {
        return async () => {
            const schema = await firstValueFrom(this.schema$);
            const multiple = await firstValueFrom(this.multiple$);
            const type = schema["x-schema-form"]?.type;
            const createdModel = await this.smallstackTypeRegistry.openEditor(type);
            if (createdModel) {
                await (await this.rxCollectionService.getCollection(type)).rxCollection.upsert(createdModel);
                if (multiple) {
                    const currentValue = await firstValueFrom(this.value$);
                    if (currentValue instanceof Array) {
                        if (currentValue?.includes(createdModel.id))
                            await this.setValue(currentValue.filter((entry) => entry !== createdModel.id));
                        else
                            await this.setValue(onlyUnique([...currentValue, createdModel.id]));
                    }
                    else
                        await this.setValue([createdModel.id]);
                }
                else {
                    await this.setValue(createdModel.id);
                    this.overlay.closeOverlay();
                }
            }
        };
    }
    editLinkedModel(modelId) {
        return async () => {
            const schema = await firstValueFrom(this.schema$);
            const type = schema["x-schema-form"]?.type;
            const model = (await (await this.rxCollectionService.getCollection(type)).rxCollection.findOne(modelId).exec())?.toJSON();
            const createdModel = await this.smallstackTypeRegistry.openEditor(type, model);
            if (createdModel)
                await (await this.rxCollectionService.getCollection(type)).rxCollection.upsert(createdModel);
        };
    }
    async addCurrent() {
        let values = await firstValueFrom(this.value$);
        const options = await firstValueFrom(this.selectOptions$);
        if (!values || values.length === 0)
            values = [];
        options?.forEach((option) => {
            if (!values.includes(option.value))
                values = [...values, option.value];
        });
        await this.setValue(values);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: SelectInputWidgetComponent, deps: [{ token: DOCUMENT }, { token: i1.FrontendTypeRegistry }, { token: i1.RxCollectionService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: SelectInputWidgetComponent, isStandalone: true, selector: "ng-component", viewQueries: [{ propertyName: "overlay", first: true, predicate: OverlayComponent, descendants: true }], usesInheritance: true, ngImport: i0, template: "<ng-container *rxLet=\"path$; let path\">\n  <smallstack-form-input-container\n    [options]=\"options$ | push\"\n    [schema]=\"schema$ | push\"\n    [path]=\"path\"\n    [validationErrorText$]=\"validationErrorText$\"\n    attr.data-test=\"schema-form-widget-select-{{ path }}\"\n  >\n    <div class=\"join w-full\">\n      <input\n        (click)=\"overlay.openOverlay()\"\n        type=\"text\"\n        class=\"input input-bordered w-full cursor-pointer join-item\"\n        readonly\n        [ngModel]=\"selectedValue$ | push\"\n        attr.data-test=\"schema-form-widget-select-{{ path }}-select\"\n      />\n      <button\n        *rxIf=\"showAddBtn$\"\n        [loadingFn]=\"add()\"\n        class=\"btn btn-secondary join-item\"\n        attr.data-test=\"schema-form-widget-select-{{ path }}-add-btn\"\n      >\n        <smallstack-icon name=\"add\" size=\"16\" theme=\"fluency-systems-regular\"></smallstack-icon>\n      </button>\n      <button\n        (click)=\"overlay.openOverlay()\"\n        class=\"btn btn-secondary join-item\"\n        attr.data-test=\"schema-form-widget-select-{{ path }}-select-btn\"\n      >\n        <smallstack-icon\n          name=\"sort-down\"\n          size=\"16\"\n          themeColor=\"daisyTheme.secondary.textColor\"\n          theme=\"fluency-systems-regular\"\n        ></smallstack-icon>\n      </button>\n    </div>\n    <smallstack-overlay #overlay>\n      <div class=\"input-dropdown flex flex-col gap-2\">\n        <input\n          type=\"search\"\n          class=\"input input-sm input-bordered w-full\"\n          placeholder=\"Auswahl filtern...\"\n          [ngModel]=\"searchText$ | push\"\n          (ngModelChange)=\"searchText$.next($event)\"\n          attr.data-test=\"schema-form-widget-select-{{ path }}-search-bar-input\"\n        />\n        <div *rxIf=\"!(selectOptions$ | push)?.length\" class=\"text-center italic text-help p-3\">\n          Keine Eintr\u00E4ge gefunden\n        </div>\n        <div class=\"h-64 overflow-y-auto overflow-x-hidden\">\n          <div\n            *rxFor=\"let option of selectOptions$\"\n            (click)=\"selectValue(option.value)\"\n            attr.data-test=\"schema-form-widget-select-{{ path }}-option-{{ option.label | urlconform }}\"\n            attr.data-test-value=\"schema-form-widget-select-{{ path }}-option-value-{{ option.value | urlconform }}\"\n            class=\"flex flex-row gap-3 justify-start items-center hover:bg-slate-200 cursor-pointer p-3 rounded-box\"\n          >\n            <input\n              *rxIf=\"multiple$\"\n              type=\"checkbox\"\n              class=\"checkbox checkbox-primary checkbox-md\"\n              [checked]=\"(value$ | push)?.includes(option.value)\"\n            />\n            <smallstack-i18n [data]=\"$any(option.label)\"></smallstack-i18n>\n          </div>\n        </div>\n        <div class=\"flex flex-row gap-1 justify-evenly\">\n          <button\n            *rxIf=\"multiple$\"\n            (click)=\"addCurrent()\"\n            class=\"btn btn-sm btn-secondary\"\n            data-test=\"select-input-overlay-reset\"\n            >Auswahl hinzuf\u00FCgen</button\n          >\n          <button\n            (click)=\"setValue(undefined); overlay.closeOverlay()\"\n            class=\"btn btn-sm btn-secondary\"\n            data-test=\"select-input-overlay-reset\"\n            >l\u00F6schen</button\n          >\n          <button\n            (click)=\"overlay.closeOverlay()\"\n            class=\"btn btn-sm btn-secondary\"\n            data-test=\"select-input-overlay-close\"\n            >schlie\u00DFen</button\n          >\n        </div>\n      </div>\n    </smallstack-overlay>\n  </smallstack-form-input-container>\n</ng-container>\n<!-- show data preview -->\n<ng-container *rxIf=\"showDetails$\">\n  <div class=\"outline-border mt-4\">\n    <div class=\"title\">Verlinkter Datensatz</div>\n    <ng-container *rxLet=\"value$; let value\">\n      <ng-container *rxIf=\"isArray(value); else noArray\">\n        <div class=\"flex flex-col gap-2\">\n          <ng-container *rxFor=\"let value of value$\">\n            <ng-container [ngTemplateOutlet]=\"preview\" [ngTemplateOutletContext]=\"{ $implicit: value }\"></ng-container>\n          </ng-container>\n        </div>\n      </ng-container>\n      <ng-template #noArray>\n        <ng-container [ngTemplateOutlet]=\"preview\" [ngTemplateOutletContext]=\"{ $implicit: value }\"></ng-container>\n      </ng-template>\n    </ng-container>\n  </div>\n</ng-container>\n\n<ng-template #preview let-value>\n  <smallstack-type-details [type]=\"type$ | push\" [modelId]=\"value\"></smallstack-type-details>\n  <div class=\"flex flex-row justify-end\">\n    <button class=\"btn btn-secondary btn-sm\" [loadingFn]=\"editLinkedModel(value)\">Bearbeiten</button>\n  </div>\n</ng-template>\n", dependencies: [{ kind: "ngmodule", type: CommonModule }, { kind: "directive", type: i2.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet", "ngTemplateOutletInjector"] }, { kind: "component", type: FormInputContainerComponent, selector: "smallstack-form-input-container", inputs: ["validationErrorText$", "options", "schema", "path"] }, { kind: "component", type: I18nComponent, selector: "smallstack-i18n", inputs: ["data", "showMissingKey", "replacers", "locale", "translationStore"] }, { kind: "directive", type: RxIf, selector: "[rxIf]", inputs: ["rxIf", "rxIfStrategy", "rxIfElse", "rxIfThen", "rxIfSuspense", "rxIfComplete", "rxIfError", "rxIfContextTrigger", "rxIfNextTrigger", "rxIfSuspenseTrigger", "rxIfErrorTrigger", "rxIfCompleteTrigger", "rxIfParent", "rxIfPatchZone", "rxIfRenderCallback"] }, { kind: "pipe", type: RxPush, name: "push" }, { kind: "directive", type: RxLet, selector: "[rxLet]", inputs: ["rxLet", "rxLetStrategy", "rxLetComplete", "rxLetError", "rxLetSuspense", "rxLetContextTrigger", "rxLetCompleteTrigger", "rxLetErrorTrigger", "rxLetSuspenseTrigger", "rxLetNextTrigger", "rxLetRenderCallback", "rxLetParent", "rxLetPatchZone"], outputs: ["rendered"] }, { kind: "directive", type: RxFor, selector: "[rxFor][rxForOf]", inputs: ["rxForOf", "rxForTemplate", "rxForStrategy", "rxForParent", "rxForPatchZone", "rxForTrackBy", "rxForRenderCallback"] }, { kind: "directive", type: LoadingElementDirective, selector: "[loadingFn]", inputs: ["loadingFn", "isLoading"], exportAs: ["loadingFn"] }, { kind: "pipe", type: UrlConformPipe, name: "urlconform" }, { kind: "component", type: OverlayComponent, selector: "smallstack-overlay", inputs: ["hasBackdrop"] }, { kind: "component", type: IconComponent, selector: "smallstack-icon", inputs: ["theme", "size", "name", "alias", "action", "actionSize", "spinning", "actionSpinning", "color", "themeColor", "actionColor", "badge", "dynamic", "badgeColor"], outputs: ["iconError"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1$1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1$1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1$1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: TypeDetailsComponent, selector: "smallstack-type-details", inputs: ["type", "modelId"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: SelectInputWidgetComponent, decorators: [{
            type: Component,
            args: [{ changeDetection: ChangeDetectionStrategy.OnPush, standalone: true, imports: [
                        CommonModule,
                        FormInputContainerComponent,
                        I18nComponent,
                        RxIf,
                        RxPush,
                        RxLet,
                        RxFor,
                        LoadingElementDirective,
                        UrlConformPipe,
                        OverlayComponent,
                        IconComponent,
                        FormsModule,
                        JsonPipe,
                        TypeDetailsComponent
                    ], template: "<ng-container *rxLet=\"path$; let path\">\n  <smallstack-form-input-container\n    [options]=\"options$ | push\"\n    [schema]=\"schema$ | push\"\n    [path]=\"path\"\n    [validationErrorText$]=\"validationErrorText$\"\n    attr.data-test=\"schema-form-widget-select-{{ path }}\"\n  >\n    <div class=\"join w-full\">\n      <input\n        (click)=\"overlay.openOverlay()\"\n        type=\"text\"\n        class=\"input input-bordered w-full cursor-pointer join-item\"\n        readonly\n        [ngModel]=\"selectedValue$ | push\"\n        attr.data-test=\"schema-form-widget-select-{{ path }}-select\"\n      />\n      <button\n        *rxIf=\"showAddBtn$\"\n        [loadingFn]=\"add()\"\n        class=\"btn btn-secondary join-item\"\n        attr.data-test=\"schema-form-widget-select-{{ path }}-add-btn\"\n      >\n        <smallstack-icon name=\"add\" size=\"16\" theme=\"fluency-systems-regular\"></smallstack-icon>\n      </button>\n      <button\n        (click)=\"overlay.openOverlay()\"\n        class=\"btn btn-secondary join-item\"\n        attr.data-test=\"schema-form-widget-select-{{ path }}-select-btn\"\n      >\n        <smallstack-icon\n          name=\"sort-down\"\n          size=\"16\"\n          themeColor=\"daisyTheme.secondary.textColor\"\n          theme=\"fluency-systems-regular\"\n        ></smallstack-icon>\n      </button>\n    </div>\n    <smallstack-overlay #overlay>\n      <div class=\"input-dropdown flex flex-col gap-2\">\n        <input\n          type=\"search\"\n          class=\"input input-sm input-bordered w-full\"\n          placeholder=\"Auswahl filtern...\"\n          [ngModel]=\"searchText$ | push\"\n          (ngModelChange)=\"searchText$.next($event)\"\n          attr.data-test=\"schema-form-widget-select-{{ path }}-search-bar-input\"\n        />\n        <div *rxIf=\"!(selectOptions$ | push)?.length\" class=\"text-center italic text-help p-3\">\n          Keine Eintr\u00E4ge gefunden\n        </div>\n        <div class=\"h-64 overflow-y-auto overflow-x-hidden\">\n          <div\n            *rxFor=\"let option of selectOptions$\"\n            (click)=\"selectValue(option.value)\"\n            attr.data-test=\"schema-form-widget-select-{{ path }}-option-{{ option.label | urlconform }}\"\n            attr.data-test-value=\"schema-form-widget-select-{{ path }}-option-value-{{ option.value | urlconform }}\"\n            class=\"flex flex-row gap-3 justify-start items-center hover:bg-slate-200 cursor-pointer p-3 rounded-box\"\n          >\n            <input\n              *rxIf=\"multiple$\"\n              type=\"checkbox\"\n              class=\"checkbox checkbox-primary checkbox-md\"\n              [checked]=\"(value$ | push)?.includes(option.value)\"\n            />\n            <smallstack-i18n [data]=\"$any(option.label)\"></smallstack-i18n>\n          </div>\n        </div>\n        <div class=\"flex flex-row gap-1 justify-evenly\">\n          <button\n            *rxIf=\"multiple$\"\n            (click)=\"addCurrent()\"\n            class=\"btn btn-sm btn-secondary\"\n            data-test=\"select-input-overlay-reset\"\n            >Auswahl hinzuf\u00FCgen</button\n          >\n          <button\n            (click)=\"setValue(undefined); overlay.closeOverlay()\"\n            class=\"btn btn-sm btn-secondary\"\n            data-test=\"select-input-overlay-reset\"\n            >l\u00F6schen</button\n          >\n          <button\n            (click)=\"overlay.closeOverlay()\"\n            class=\"btn btn-sm btn-secondary\"\n            data-test=\"select-input-overlay-close\"\n            >schlie\u00DFen</button\n          >\n        </div>\n      </div>\n    </smallstack-overlay>\n  </smallstack-form-input-container>\n</ng-container>\n<!-- show data preview -->\n<ng-container *rxIf=\"showDetails$\">\n  <div class=\"outline-border mt-4\">\n    <div class=\"title\">Verlinkter Datensatz</div>\n    <ng-container *rxLet=\"value$; let value\">\n      <ng-container *rxIf=\"isArray(value); else noArray\">\n        <div class=\"flex flex-col gap-2\">\n          <ng-container *rxFor=\"let value of value$\">\n            <ng-container [ngTemplateOutlet]=\"preview\" [ngTemplateOutletContext]=\"{ $implicit: value }\"></ng-container>\n          </ng-container>\n        </div>\n      </ng-container>\n      <ng-template #noArray>\n        <ng-container [ngTemplateOutlet]=\"preview\" [ngTemplateOutletContext]=\"{ $implicit: value }\"></ng-container>\n      </ng-template>\n    </ng-container>\n  </div>\n</ng-container>\n\n<ng-template #preview let-value>\n  <smallstack-type-details [type]=\"type$ | push\" [modelId]=\"value\"></smallstack-type-details>\n  <div class=\"flex flex-row justify-end\">\n    <button class=\"btn btn-secondary btn-sm\" [loadingFn]=\"editLinkedModel(value)\">Bearbeiten</button>\n  </div>\n</ng-template>\n" }]
        }], ctorParameters: function () { return [{ type: Document, decorators: [{
                    type: Inject,
                    args: [DOCUMENT]
                }] }, { type: i1.FrontendTypeRegistry }, { type: i1.RxCollectionService }]; }, propDecorators: { overlay: [{
                type: ViewChild,
                args: [OverlayComponent]
            }] } });

export { SelectInputWidgetComponent };
//# sourceMappingURL=smallstack-form-widgets-select-input-widget.component-e45d9900.mjs.map
