import { JsonPipe, AsyncPipe } from '@angular/common';
import * as i0 from '@angular/core';
import { signal, Component, ChangeDetectionStrategy } from '@angular/core';
import * as i1 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import { RxLet } from '@rx-angular/template/let';
import { RxPush } from '@rx-angular/template/push';
import { OverlayComponent, CloseDropDownOnClickDirective, DebugComponentComponent } from '@smallstack/common-components';
import { distinctUntilChangedObj, isNonEmptyString } from '@smallstack/utils';
import { BehaviorSubject, combineLatest, map, tap } from 'rxjs';
import { F as FilterBaseWidgetComponent } from './smallstack-form-widgets-filter-base-widget.component-1bb6ed87.mjs';
import { toObservable } from '@angular/core/rxjs-interop';
import '@angular/router';
import '@smallstack/widget-core';
import 'uuid';

class StringFilterWidgetComponent extends FilterBaseWidgetComponent {
    constructor() {
        super();
        this.inputValue$ = signal("");
        this.filterType$ = new BehaviorSubject("contains");
        this.subscribeToChanges();
    }
    subscribeToChanges() {
        // set filter on input change
        this.subscription.add(combineLatest([toObservable(this.inputValue$), this.filterType$, this.path$])
            .pipe(distinctUntilChangedObj(), map(([value, type, path]) => {
            if (isNonEmptyString(value)) {
                if (type === "contains") {
                    void this.setFilter({ [path]: { $regex: new RegExp(".*" + value + ".*", "i").toString() } });
                    void this.setUrlSyncParam(value);
                }
                else if (type === "exact") {
                    void this.setFilter({ [path]: value });
                    void this.setUrlSyncParam(value);
                }
            }
            else {
                void this.setFilter(undefined);
                void this.setUrlSyncParam(undefined);
            }
        }))
            .subscribe());
        // take value from url if present
        this.subscription.add(combineLatest([this.urlSyncValue$, this.path$]).subscribe(async ([value, path]) => {
            if (value !== undefined)
                void this.setFilter({ [path]: { $regex: new RegExp(".*" + value + ".*", "i").toString() } });
        }));
        // sync value to local form fields
        this.subscription.add(combineLatest([this.value$, this.path$])
            .pipe(map(([value, path]) => (value ? value[path] : undefined)), map((value) => value
            ? typeof value.$regex === "string" && value.$regex.startsWith("/")
                ? value.$regex.split("/")[1].replace(/\.\*/g, "")
                : value
            : undefined), map((value) => (value === undefined ? "" : value)), tap((val) => {
            this.inputValue$.set(val);
        }))
            .subscribe());
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: StringFilterWidgetComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.8", type: StringFilterWidgetComponent, isStandalone: true, selector: "smallstack-string-filter-widget", usesInheritance: true, ngImport: i0, template: "<div class=\"join w-full\">\n  <div class=\"join-item\">\n    <label\n      *rxLet=\"filterType$; let filterType\"\n      class=\"btn btn-primary rounded-r-none !font-bold !text-lg\"\n      tabindex=\"-1\"\n      (click)=\"overlay.openOverlay()\"\n    >\n      {{ filterType === \"contains\" ? \"\u22C6\" : \"=\" }}\n    </label>\n    <smallstack-overlay #overlay [hasBackdrop]=\"false\">\n      <div class=\"input-dropdown\">\n        <ul class=\"menu menu-sm w-64\">\n          <li class=\"menu-title\">Filter Modus</li>\n          <li (click)=\"filterType$.next('contains'); overlay.closeOverlay()\">\n            <a\n              ><span class=\"font-extrabold text-xl rounded-box border input-bordered w-7 text-center\">\u22C6</span>\n              enth\u00E4lt</a\n            >\n          </li>\n          <li (click)=\"filterType$.next('exact'); overlay.closeOverlay()\">\n            <a\n              ><span class=\"font-extrabold text-xl rounded-box border input-bordered w-7 text-center\">=</span> stimmt\n              exakt \u00FCberein</a\n            >\n          </li>\n        </ul>\n      </div>\n    </smallstack-overlay>\n  </div>\n  <input\n    type=\"search\"\n    class=\"input input-bordered w-full join-item\"\n    [ngModel]=\"inputValue$()\"\n    (ngModelChange)=\"inputValue$.set($event)\"\n    attr.data-test=\"string-filter-widget-input-{{ path$ | push }}\"\n  />\n</div>\n", dependencies: [{ kind: "pipe", type: RxPush, name: "push" }, { kind: "directive", type: RxLet, selector: "[rxLet]", inputs: ["rxLet", "rxLetStrategy", "rxLetComplete", "rxLetError", "rxLetSuspense", "rxLetContextTrigger", "rxLetCompleteTrigger", "rxLetErrorTrigger", "rxLetSuspenseTrigger", "rxLetNextTrigger", "rxLetRenderCallback", "rxLetParent", "rxLetPatchZone"], outputs: ["rendered"] }, { kind: "ngmodule", type: FormsModule }, { kind: "directive", type: i1.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i1.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i1.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: OverlayComponent, selector: "smallstack-overlay", inputs: ["hasBackdrop"] }], changeDetection: i0.ChangeDetectionStrategy.OnPush }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.8", ngImport: i0, type: StringFilterWidgetComponent, decorators: [{
            type: Component,
            args: [{ selector: "smallstack-string-filter-widget", standalone: true, changeDetection: ChangeDetectionStrategy.OnPush, imports: [
                        RxPush,
                        RxLet,
                        FormsModule,
                        CloseDropDownOnClickDirective,
                        JsonPipe,
                        OverlayComponent,
                        DebugComponentComponent,
                        AsyncPipe
                    ], template: "<div class=\"join w-full\">\n  <div class=\"join-item\">\n    <label\n      *rxLet=\"filterType$; let filterType\"\n      class=\"btn btn-primary rounded-r-none !font-bold !text-lg\"\n      tabindex=\"-1\"\n      (click)=\"overlay.openOverlay()\"\n    >\n      {{ filterType === \"contains\" ? \"\u22C6\" : \"=\" }}\n    </label>\n    <smallstack-overlay #overlay [hasBackdrop]=\"false\">\n      <div class=\"input-dropdown\">\n        <ul class=\"menu menu-sm w-64\">\n          <li class=\"menu-title\">Filter Modus</li>\n          <li (click)=\"filterType$.next('contains'); overlay.closeOverlay()\">\n            <a\n              ><span class=\"font-extrabold text-xl rounded-box border input-bordered w-7 text-center\">\u22C6</span>\n              enth\u00E4lt</a\n            >\n          </li>\n          <li (click)=\"filterType$.next('exact'); overlay.closeOverlay()\">\n            <a\n              ><span class=\"font-extrabold text-xl rounded-box border input-bordered w-7 text-center\">=</span> stimmt\n              exakt \u00FCberein</a\n            >\n          </li>\n        </ul>\n      </div>\n    </smallstack-overlay>\n  </div>\n  <input\n    type=\"search\"\n    class=\"input input-bordered w-full join-item\"\n    [ngModel]=\"inputValue$()\"\n    (ngModelChange)=\"inputValue$.set($event)\"\n    attr.data-test=\"string-filter-widget-input-{{ path$ | push }}\"\n  />\n</div>\n" }]
        }], ctorParameters: function () { return []; } });

export { StringFilterWidgetComponent };
//# sourceMappingURL=smallstack-form-widgets-string-filter-widget.component-2b4ca74e.mjs.map
